package increasemobs.core;

import java.io.File;
import java.util.List;

import org.apache.logging.log4j.Level;

import com.google.common.collect.Lists;

import cpw.mods.fml.common.FMLLog;
import cpw.mods.fml.common.Loader;
import net.minecraft.util.MathHelper;
import net.minecraft.util.StatCollector;
import net.minecraftforge.common.config.Configuration;
import net.minecraftforge.common.config.Property;

public class Config
{
	public static Configuration config;

	public static boolean monster;
	public static int monsterSpawn;
	public static int[] monsterDimensions;

	public static boolean ambient;
	public static int ambientSpawn;
	public static int[] ambientDimensions;

	public static boolean water;
	public static int waterSpawn;
	public static int[] waterDimensions;

	public static void syncConfig()
	{
		if (config == null)
		{
			File file = new File(Loader.instance().getConfigDir(), "IncreaseMobs.cfg");
			config = new Configuration(file, true);

			try
			{
				config.load();
			}
			catch (Exception e)
			{
				File dest = new File(file.getParentFile(), file.getName() + ".bak");

				if (dest.exists())
				{
					dest.delete();
				}

				file.renameTo(dest);

				FMLLog.log(Level.ERROR, e, "A critical error occured reading the " + file.getName() + " file, defaults will be used - the invalid file is backed up at " + dest.getName());
			}
		}

		String category = Configuration.CATEGORY_GENERAL;
		Property prop;
		List<String> propOrder = Lists.newArrayList();

		category = "monster";
		config.setCategoryComment(category, "If multiplayer, server-side only.");

		prop = config.get(category, "enabled", true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		monster = prop.getBoolean(monster);
		prop = config.get(category, "spawnWeight", 100);
		prop.setMinValue(0).setMaxValue(10000).setRequiresMcRestart(true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		prop.comment += " [range: " + prop.getMinValue() + " ~ " + prop.getMaxValue() + ", default: " + prop.getDefault() + "]";
		propOrder.add(prop.getName());
		monsterSpawn = MathHelper.clamp_int(prop.getInt(monsterSpawn), Integer.parseInt(prop.getMinValue()), Integer.parseInt(prop.getMaxValue()));
		prop = config.get(category, "dimensions", new int[] {0, -1, 1});
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		monsterDimensions = prop.getIntList();

		config.setCategoryPropertyOrder(category, propOrder);

		propOrder = Lists.newArrayList();

		category = "ambient";
		config.setCategoryComment(category, "If multiplayer, server-side only.");

		prop = config.get(category, "enabled", true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		ambient = prop.getBoolean(ambient);
		prop = config.get(category, "spawnWeight", 25);
		prop.setMinValue(0).setMaxValue(10000).setRequiresMcRestart(true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		prop.comment += " [range: " + prop.getMinValue() + " ~ " + prop.getMaxValue() + ", default: " + prop.getDefault() + "]";
		propOrder.add(prop.getName());
		ambientSpawn = MathHelper.clamp_int(prop.getInt(ambientSpawn), Integer.parseInt(prop.getMinValue()), Integer.parseInt(prop.getMaxValue()));
		prop = config.get(category, "dimensions", new int[] {0});
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		ambientDimensions = prop.getIntList();

		config.setCategoryPropertyOrder(category, propOrder);

		propOrder = Lists.newArrayList();

		category = "waterCreature";
		config.setCategoryComment(category, "If multiplayer, server-side only.");

		prop = config.get(category, "enabled", true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		water = prop.getBoolean(water);
		prop = config.get(category, "spawnWeight", 10);
		prop.setMinValue(0).setMaxValue(10000).setRequiresMcRestart(true);
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		prop.comment += " [range: " + prop.getMinValue() + " ~ " + prop.getMaxValue() + ", default: " + prop.getDefault() + "]";
		propOrder.add(prop.getName());
		waterSpawn = MathHelper.clamp_int(prop.getInt(waterSpawn), Integer.parseInt(prop.getMinValue()), Integer.parseInt(prop.getMaxValue()));
		prop = config.get(category, "dimensions", new int[] {0});
		prop.setLanguageKey(IncreaseMobs.CONFIG_LANG + "entry." + prop.getName());
		prop.comment = StatCollector.translateToLocal(prop.getLanguageKey() + ".tooltip");
		propOrder.add(prop.getName());
		waterDimensions = prop.getIntList();

		config.setCategoryPropertyOrder(category, propOrder);

		if (config.hasChanged())
		{
			config.save();
		}
	}
}