package increasemobs.core;

import java.util.Map;

import org.apache.commons.lang3.ArrayUtils;

import net.minecraft.block.material.Material;
import net.minecraft.entity.EnumCreatureType;
import net.minecraft.entity.monster.IMob;
import net.minecraft.entity.passive.EntityAmbientCreature;
import net.minecraft.entity.passive.EntityWaterMob;
import net.minecraft.world.World;
import net.minecraft.world.biome.Biome;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.common.util.EnumHelper;
import net.minecraftforge.event.world.WorldEvent.PotentialSpawns;
import net.minecraftforge.fml.client.event.ConfigChangedEvent.OnConfigChangedEvent;
import net.minecraftforge.fml.common.Mod;
import net.minecraftforge.fml.common.Mod.EventHandler;
import net.minecraftforge.fml.common.event.FMLPreInitializationEvent;
import net.minecraftforge.fml.common.eventhandler.EventPriority;
import net.minecraftforge.fml.common.eventhandler.SubscribeEvent;
import net.minecraftforge.fml.common.network.NetworkCheckHandler;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

@Mod(modid = IncreaseMobs.MODID, guiFactory = "increasemobs.client.IncreaseGuiFactory")
public class IncreaseMobs
{
	public static final String
	MODID = "increasemobs",
	CONFIG_LANG = "increasemobs.config.";

	public static EnumCreatureType MONSTER;
	public static EnumCreatureType AMBIENT;
	public static EnumCreatureType WATER_CREATURE;

	@EventHandler
	public void preInit(FMLPreInitializationEvent event)
	{
		Config.syncConfig();

		if (Config.monster)
		{
			MONSTER = EnumHelper.addCreatureType("increaseMonster", IMob.class, Config.monsterSpawn, Material.AIR, false, false);
		}

		if (Config.ambient)
		{
			AMBIENT = EnumHelper.addCreatureType("increaseAmbient", EntityAmbientCreature.class, Config.ambientSpawn, Material.AIR, true, false);
		}

		if (Config.water)
		{
			WATER_CREATURE = EnumHelper.addCreatureType("increaseWaterCreature", EntityWaterMob.class, Config.waterSpawn, Material.WATER, true, false);
		}

		MinecraftForge.EVENT_BUS.register(this);
	}

	@NetworkCheckHandler
	public boolean netCheckHandler(Map<String, String> mods, Side side)
	{
		return true;
	}

	@SideOnly(Side.CLIENT)
	@SubscribeEvent
	public void onConfigChanged(OnConfigChangedEvent event)
	{
		if (event.getModID().equals(MODID))
		{
			Config.syncConfig();
		}
	}

	@SubscribeEvent(priority = EventPriority.HIGHEST, receiveCanceled = true)
	public void onPotentialSpawns(PotentialSpawns event)
	{
		World world = event.getWorld();
		Biome biome = world.getBiomeGenForCoords(event.getPos());
		EnumCreatureType type = event.getType();

		if (Config.monster && type == MONSTER)
		{
			if (Config.monsterDimensions != null && (Config.monsterDimensions.length <= 0 || ArrayUtils.contains(Config.monsterDimensions, world.provider.getDimension())))
			{
				event.getList().addAll(biome.getSpawnableList(EnumCreatureType.MONSTER));
			}
		}

		if (Config.ambient && type == AMBIENT)
		{
			if (Config.ambientDimensions != null && (Config.ambientDimensions.length <= 0 || ArrayUtils.contains(Config.ambientDimensions, world.provider.getDimension())))
			{
				event.getList().addAll(biome.getSpawnableList(EnumCreatureType.AMBIENT));
			}
		}

		if (Config.water && type == WATER_CREATURE)
		{
			if (Config.waterDimensions != null && (Config.waterDimensions.length <= 0 || ArrayUtils.contains(Config.waterDimensions, world.provider.getDimension())))
			{
				event.getList().addAll(biome.getSpawnableList(EnumCreatureType.WATER_CREATURE));
			}
		}
	}
}