package increasemobs.core;

import java.util.Map;

import org.apache.commons.lang3.ArrayUtils;

import cpw.mods.fml.client.event.ConfigChangedEvent.OnConfigChangedEvent;
import cpw.mods.fml.common.FMLCommonHandler;
import cpw.mods.fml.common.Mod;
import cpw.mods.fml.common.Mod.EventHandler;
import cpw.mods.fml.common.event.FMLPreInitializationEvent;
import cpw.mods.fml.common.eventhandler.EventPriority;
import cpw.mods.fml.common.eventhandler.SubscribeEvent;
import cpw.mods.fml.common.network.NetworkCheckHandler;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import net.minecraft.block.material.Material;
import net.minecraft.entity.EnumCreatureType;
import net.minecraft.entity.monster.IMob;
import net.minecraft.entity.passive.EntityAmbientCreature;
import net.minecraft.entity.passive.EntityWaterMob;
import net.minecraft.world.World;
import net.minecraft.world.biome.BiomeGenBase;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.common.util.EnumHelper;
import net.minecraftforge.event.world.WorldEvent.PotentialSpawns;

@Mod(modid = IncreaseMobs.MODID, guiFactory = "increasemobs.client.IncreaseGuiFactory")
public class IncreaseMobs
{
	public static final String
	MODID = "increasemobs",
	CONFIG_LANG = "increasemobs.config.";

	public static EnumCreatureType monster;
	public static EnumCreatureType ambient;
	public static EnumCreatureType waterCreature;

	@EventHandler
	public void preInit(FMLPreInitializationEvent event)
	{
		Config.syncConfig();

		if (Config.monster)
		{
			monster = EnumHelper.addCreatureType("increaseMonster", IMob.class, Config.monsterSpawn, Material.air, false, false);
		}

		if (Config.ambient)
		{
			ambient = EnumHelper.addCreatureType("increaseAmbient", EntityAmbientCreature.class, Config.ambientSpawn, Material.air, true, false);
		}

		if (Config.water)
		{
			waterCreature = EnumHelper.addCreatureType("increaseWaterCreature", EntityWaterMob.class, Config.waterSpawn, Material.water, true, false);
		}

		FMLCommonHandler.instance().bus().register(this);

		MinecraftForge.EVENT_BUS.register(this);
	}

	@NetworkCheckHandler
	public boolean netCheckHandler(Map<String, String> mods, Side side)
	{
		return true;
	}

	@SideOnly(Side.CLIENT)
	@SubscribeEvent
	public void onConfigChanged(OnConfigChangedEvent event)
	{
		if (event.modID.equals(MODID))
		{
			Config.syncConfig();
		}
	}

	@SubscribeEvent(priority = EventPriority.HIGHEST, receiveCanceled = true)
	public void onPotentialSpawns(PotentialSpawns event)
	{
		World world = event.world;
		int x = event.x;
		int z = event.z;
		BiomeGenBase biome = world.getBiomeGenForCoords(x, z);
		EnumCreatureType type = event.type;

		if (Config.monster && type == monster)
		{
			if (Config.monsterDimensions != null && (Config.monsterDimensions.length <= 0 || ArrayUtils.contains(Config.monsterDimensions, world.provider.dimensionId)))
			{
				event.list.addAll(biome.getSpawnableList(EnumCreatureType.monster));
			}
		}

		if (Config.ambient && type == ambient)
		{
			if (Config.ambientDimensions != null && (Config.ambientDimensions.length <= 0 || ArrayUtils.contains(Config.ambientDimensions, world.provider.dimensionId)))
			{
				event.list.addAll(biome.getSpawnableList(EnumCreatureType.ambient));
			}
		}

		if (Config.water && type == waterCreature)
		{
			if (Config.waterDimensions != null && (Config.waterDimensions.length <= 0 || ArrayUtils.contains(Config.waterDimensions, world.provider.dimensionId)))
			{
				event.list.addAll(biome.getSpawnableList(EnumCreatureType.waterCreature));
			}
		}
	}
}